==> nuiton-js-wro-1.0.2-sources.jar: org/nuiton/js/wro/NuitonJsWroManagerFactory.java <==
package org.nuiton.js.wro;

/*
 * #%L
 * Nuiton JS :: WRO
 * $Id: NuitonJsWroManagerFactory.java 168 2013-07-19 21:53:33Z echatellier $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-js/tags/nuiton-js-1.0.2/nuiton-js-wro/src/main/java/org/nuiton/js/wro/NuitonJsWroManagerFactory.java $
 * %%
 * Copyright (C) 2012 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.util.Map;
import java.util.Properties;
import ro.isdc.wro.manager.factory.ConfigurableWroManagerFactory;
import ro.isdc.wro.model.factory.WroModelFactory;
import ro.isdc.wro.model.resource.processor.ResourcePreProcessor;

/**
 * Surcharge pour force la recherche du fichier /WEB-INF/nuiton-js.properties
 * a la place de /WEB-INF/wro.properties. Et chargement de certaine  valeur par
 * defaut dans de la config
 *
 * @author poussin
 * @version $Revision: 168 $
 *
 * Last update: $Date: 2013-07-19 23:53:33 +0200 (Fri, 19 Jul 2013) $
 * by : $Author: echatellier $
 */
public class NuitonJsWroManagerFactory extends ConfigurableWroManagerFactory {

    @Override
    protected WroModelFactory newModelFactory() {
        return new NuitonJsXmlModelFactory();
    }

    @Override
    protected Properties newConfigProperties() {
        Properties result = new NuitonJsWroConfigurationFactory().initProperties();
        return result;
    }

    @Override
    protected void contributePreProcessors(Map<String, ResourcePreProcessor> map) {
        super.contributePreProcessors(map);
        map.put(ForceCssDataUriPreProcessor.ALIAS, new ForceCssDataUriPreProcessor());
    }

}

==> nuiton-js-wro-1.0.3-sources.jar: org/nuiton/js/wro/NuitonJsWroManagerFactory.java <==
package org.nuiton.js.wro;

/*
 * #%L
 * Nuiton JS :: WRO
 * $Id: NuitonJsWroManagerFactory.java 168 2013-07-19 21:53:33Z echatellier $
 * $HeadURL: https://svn.nuiton.org/nuiton-js/tags/nuiton-js-1.0.3/nuiton-js-wro/src/main/java/org/nuiton/js/wro/NuitonJsWroManagerFactory.java $
 * %%
 * Copyright (C) 2012 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import java.util.Map;
import java.util.Properties;
import ro.isdc.wro.manager.factory.ConfigurableWroManagerFactory;
import ro.isdc.wro.model.factory.WroModelFactory;
import ro.isdc.wro.model.resource.processor.ResourcePreProcessor;

/**
 * Surcharge pour force la recherche du fichier /WEB-INF/nuiton-js.properties
 * a la place de /WEB-INF/wro.properties. Et chargement de certaine  valeur par
 * defaut dans de la config
 *
 * @author poussin
 * @version $Revision: 168 $
 *
 * Last update: $Date: 2013-07-19 23:53:33 +0200 (Fri, 19 Jul 2013) $
 * by : $Author: echatellier $
 */
public class NuitonJsWroManagerFactory extends ConfigurableWroManagerFactory {

    @Override
    protected WroModelFactory newModelFactory() {
        return new NuitonJsXmlModelFactory();
    }

    @Override
    protected Properties newConfigProperties() {
        Properties result = new NuitonJsWroConfigurationFactory().initProperties();
        return result;
    }

    @Override
    protected void contributePreProcessors(Map<String, ResourcePreProcessor> map) {
        super.contributePreProcessors(map);
        map.put(ForceCssDataUriPreProcessor.ALIAS, new ForceCssDataUriPreProcessor());
    }

}
